@@ -26,8 +26,8 @@
  *   that compiling, linking, and/or using OpenSSL is allowed.
  *   
  *   
- *   $Rev: 155 $
- *   $Date: 2012-04-26 15:41:09 +0200 (Thu, 26 Apr 2012) $
+ *   $Rev: 162 $
+ *   $Date: 2013-03-08 14:56:32 +0100 (Fri, 08 Mar 2013) $
  *   
  *   
 */
@@ -140,6 +140,8 @@ OphcrackGUI::OphcrackGUI(ophcrack_t *crack) : QMainWindow() {
   tableModel->insertRoot(ntseven);
   tableModel->insertRoot(lmflash);
   tableModel->insertRoot(nteightxl);
+  tableModel->insertRoot(ntspecialxl);
+  tableModel->insertRoot(probaTable);
 
   // Associate a menu to the load button.
 
