@@ -26,8 +26,8 @@
  *   that compiling, linking, and/or using OpenSSL is allowed.
  *   
  *   
- *   $Rev: 155 $
- *   $Date: 2012-04-26 15:41:09 +0200 (Thu, 26 Apr 2012) $
+ *   $Rev: 158 $
+ *   $Date: 2013-02-11 15:45:13 +0100 (Mon, 11 Feb 2013) $
  *   
  *   
 */
@@ -209,6 +209,8 @@ int lmtable_lookup_idx(void *hsh_, void *tbl_, void *el_) {
   else {
     FILE *idxfile = tbl->idxfile;
 
+    el->low = 0;
+    el->high = 0;
     fseeko(idxfile, 4*prefix, SEEK_SET);
     fread(&el->low, 4, 1, idxfile);
     fread(&el->high, 4, 1, idxfile);
