@@ -26,8 +26,8 @@
  *   that compiling, linking, and/or using OpenSSL is allowed.
  *   
  *   
- *   $Rev: 155 $
- *   $Date: 2012-04-26 15:41:09 +0200 (Thu, 26 Apr 2012) $
+ *   $Rev: 162 $
+ *   $Date: 2013-03-08 14:56:32 +0100 (Fri, 08 Mar 2013) $
  *   
  *   
 */
@@ -55,6 +55,8 @@
 #include "ntseven.h"
 #include "lmflash.h"
 #include "nteightxl.h"
+#include "ntspecialxl.h"
+#include "probaTable.h"
 #include "message.h"
 /*-------------------------------------------------------------------------*/
 ophcrack_t *ophcrack_alloc(int nthreads, arg_t *arg) {
@@ -156,6 +158,14 @@ int ophcrack_setup_table(table_t *tbl) {
     ret = nteightxl_setup(tbl);
     break;
 
+  case ntspecialxl:
+    ret = ntspecialxl_setup(tbl);
+    break;
+
+  case probaTable:
+    ret = probaTable_setup(tbl);
+    break;
+
   case unknown:
     ret = -1;
     break;
@@ -538,7 +548,7 @@ ophtask_t *ophcrack_find(ophcrack_t *crack, ophtask_t *task, int id) {
 
     if (arg->debug) {
       uint32_t prefix  = tosearch[i]->prefix;
-      uint64_t postfix = tosearch[i]->postfix;
+      uint16_t postfix = tosearch[i]->postfix;
 
       fprintf(arg->lfile, 
 	      "prefix = %u, postfix = %u.\n", 
@@ -617,7 +627,7 @@ ophtask_t *ophcrack_lookup_idx(ophcrack_t *crack, ophtask_t *task, int id) {
       }
 
       uint32_t prefix  = tosearch[i]->prefix;
-      uint64_t postfix = tosearch[i]->postfix;
+      uint16_t postfix = tosearch[i]->postfix;
       
       fprintf(arg->lfile, "#%d in table %s,%d ", hid, name, idx);
       fprintf(arg->lfile, "at column %d, ", cmax-i);
@@ -628,10 +638,10 @@ ophtask_t *ophcrack_lookup_idx(ophcrack_t *crack, ophtask_t *task, int id) {
     tbl->lookup_idx(hsh, tbl, tosearch[i]);
 
     if (arg->debug) {
-      uint32_t low  = tosearch[i]->low;
-      uint32_t high = tosearch[i]->high;
+      uint64_t low  = tosearch[i]->low;
+      uint64_t high = tosearch[i]->high;
 
-      fprintf(arg->lfile, "low = %u, high = %u.\n", low, high);
+      fprintf(arg->lfile, "low = %llu, high = %llu.\n", (long long unsigned)low, (long long unsigned)high);
       pthread_mutex_unlock(mutex);
     }
   }
@@ -697,15 +707,15 @@ ophtask_t *ophcrack_lookup_end(ophcrack_t *crack, ophtask_t *task, int id) {
       }
 
       uint32_t prefix  = tosearch[i]->prefix;
-      uint64_t postfix = tosearch[i]->postfix;
-      uint32_t low  = tosearch[i]->low;
-      uint32_t high = tosearch[i]->high;
+      uint16_t postfix = tosearch[i]->postfix;
+      uint64_t low  = tosearch[i]->low;
+      uint64_t high = tosearch[i]->high;
       
       fprintf(arg->lfile, "#%d in table %s,%d ", hid, name, idx);
       fprintf(arg->lfile, "at column %d, ", cmax-i);
       fprintf(arg->lfile, "with prefix = %u, ", prefix);
       fprintf(arg->lfile, "postfix = %u, ", (unsigned int)postfix);
-      fprintf(arg->lfile, "low = %u and high = %u ... ", low, high);
+      fprintf(arg->lfile, "low = %llu and high = %llu ... ", (long long unsigned)low, (long long unsigned)high);
     }
 
     int ret = tbl->lookup_end(hsh, tbl, tosearch[i]);
@@ -734,8 +744,8 @@ ophtask_t *ophcrack_lookup_end(ophcrack_t *crack, ophtask_t *task, int id) {
      increasing order of the column index. Otherwise we delete the
      task. */
 
-  if (count > 0)
-    qsort(tosearch, size, sizeof(ophel_t*), ophcrack_col_cmp);
+  if (count > 0) 
+      qsort(tosearch, size, sizeof(ophel_t*), ophcrack_col_cmp);
   else
     return task;
 
@@ -801,16 +811,16 @@ ophtask_t *ophcrack_lookup_srt(ophcrack_t *crack, ophtask_t *task, int id) {
       }
 
       uint32_t prefix  = tosearch[i]->prefix;
-      uint64_t postfix = tosearch[i]->postfix;
-      uint32_t low  = tosearch[i]->low;
-      uint32_t high = tosearch[i]->high;
+      uint16_t postfix = tosearch[i]->postfix;
+      uint64_t low  = tosearch[i]->low;
+      uint64_t high = tosearch[i]->high;
       uint64_t offset = tosearch[i]->offset;
       
       fprintf(arg->lfile, "#%d in table %s,%d ", hid, name, idx);
       fprintf(arg->lfile, "at column %d, ", cmax-i);
       fprintf(arg->lfile, "with prefix = %u, ", prefix);
       fprintf(arg->lfile, "postfix = %u, ", (unsigned int)postfix);
-      fprintf(arg->lfile, "low = %u, high = %u ", low, high);
+      fprintf(arg->lfile, "low = %llu, high = %llu ", (long long unsigned)low, (long long unsigned)high);
       fprintf(arg->lfile, "and offset = %llu ... ", (long long unsigned int)offset);
     }
     
@@ -873,16 +883,16 @@ ophtask_t *ophcrack_check(ophcrack_t *crack, ophtask_t *task, int id) {
       }
 
       uint32_t prefix  = tosearch[i]->prefix;
-      uint64_t postfix = tosearch[i]->postfix;
-      uint32_t low  = tosearch[i]->low;
-      uint32_t high = tosearch[i]->high;
+      uint16_t postfix = tosearch[i]->postfix;
+      uint64_t low  = tosearch[i]->low;
+      uint64_t high = tosearch[i]->high;
       uint64_t offset = tosearch[i]->offset;
       
       fprintf(arg->lfile, "#%d in table %s,%d ", hid, name, idx);
       fprintf(arg->lfile, "at column %d, ", cmax-i);
       fprintf(arg->lfile, "with prefix = %u, ", prefix);
       fprintf(arg->lfile, "postfix = %u, ", (unsigned int)postfix);
-      fprintf(arg->lfile, "low = %u, high = %u, ", low, high);
+      fprintf(arg->lfile, "low = %llu, high = %llu, ", (long long unsigned)low, (long long unsigned)high);
       fprintf(arg->lfile, "offset = %llu ", (long long unsigned int)offset);
       fprintf(arg->lfile, "and start = ");
       fprintf_hex(arg->lfile, tosearch[i]->pwd, 16);
